@@ -1,5 +1,7 @@
 #!/usr/bin/python3
 
+import sys
+
 from debmutate.control import (
     guess_template_type,
     )
@@ -8,6 +10,9 @@ from debmutate.reformatting import (
     GeneratedFile,
     )
 
+from lintian_brush.fixer import report_result, LintianIssue
+from lintian_brush.line_editor import LineEditor
+
 
 def rewrite_line(line):
     if not line.split(b'#', 1)[0].strip():
@@ -21,19 +26,23 @@ def rewrite_line(line):
 
 
 def fix_field_spacing(path):
-    lines = []
     changed = False
-    with open(path, 'rb') as f:
-        for oldline in f:
+    with LineEditor(path, 'b') as e:
+        for lineno, oldline in e:
             newline = rewrite_line(oldline)
             if newline != oldline:
-                changed = True
-            lines.append(newline)
-    if not changed:
-        return False
-    with open(path, 'wb') as f:
-        f.writelines(lines)
-    return True
+                if path == 'debian/control':
+                    issue = LintianIssue(
+                        'source', 'debian-control-has-unusual-field-spacing',
+                        info='line %d' % lineno)
+                    if issue.should_fix():
+                        e[lineno] = newline
+                        changed = True
+                        issue.report_fixed()
+                else:
+                    e[lineno] = newline
+                    changed = True
+    return changed
 
 
 try:
@@ -48,9 +57,13 @@ except GeneratedFile as e:
             fix_field_spacing('debian/control')
     else:
         raise
+except FileNotFoundError:
+    sys.exit(0)
 else:
-    changed = fix_field_spacing('debian/control')
+    try:
+        changed = fix_field_spacing('debian/control')
+    except FileNotFoundError:
+        sys.exit(0)
 
 if changed:
-    print('Strip unusual field spacing from debian/control.')
-    print('Fixed-Lintian-Tags: debian-control-has-unusual-field-spacing')
+    report_result('Strip unusual field spacing from debian/control.')
