@@ -4,10 +4,14 @@ from lintian_brush.fixer import (
     opinionated,
     package_is_native,
     LintianIssue,
+    is_debcargo_package,
     )
 import os
 import sys
 
+if is_debcargo_package():
+    sys.exit(0)
+
 description = None
 
 if not os.path.exists('debian/source/format'):
